python-measurement — python-measurement 1.0 documentation

### Navigation

- index
- next |
- python-measurement 1.0 documentation »

# python-measurement

Easily use and manipulate unit-aware measurement objects in Python.

django.contrib.gis.measure has these wonderful ‘Distance’ objects that can be used not only for storing a unit-aware distance measurement, but also for converting between different units and adding/subtracting these objects from one another.

This module not only provides those Distance and Area measurement objects (courtesy of Django), but also other measurements including Weight, Volume, and Temperature.

Warning

Measurements are stored internally by converting them to a floating-point number of a (generally) reasonable SI unit. Given that floating-point numbers are very slightly lossy, you should be aware of any inaccuracies that this might cause.

TLDR: Do not use this in navigation algorithms guiding probes into the atmosphere of extraterrestrial worlds.

Contents:

- Creating your own Measure Class
  - Normal Measures
- Installation
- Measures
  - Area
  - Distance
  - Energy
  - Speed
  - Temperature
  - Time
  - Volume
  - Weight
- Using Measurement Objects
- Guessing Measurements

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- python-measurement 1.0 documentation »